You are viewing a plain text version of this content. The canonical link for it is here.
Posted to cvs@httpd.apache.org by co...@apache.org on 2007/07/19 23:05:17 UTC

svn commit: r557772 - in /httpd/httpd/trunk: include/util_ldap.h modules/aaa/mod_authnz_ldap.c modules/ldap/util_ldap.c

Author: covener
Date: Thu Jul 19 14:05:16 2007
New Revision: 557772

URL: http://svn.apache.org/viewvc?view=rev&rev=557772
Log:
revert revision 555470

Modified:
    httpd/httpd/trunk/include/util_ldap.h
    httpd/httpd/trunk/modules/aaa/mod_authnz_ldap.c
    httpd/httpd/trunk/modules/ldap/util_ldap.c

Modified: httpd/httpd/trunk/include/util_ldap.h
URL: http://svn.apache.org/viewvc/httpd/httpd/trunk/include/util_ldap.h?view=diff&rev=557772&r1=557771&r2=557772
==============================================================================
--- httpd/httpd/trunk/modules/aaa/mod_authnz_ldap.c (original)
+++ httpd/httpd/trunk/modules/aaa/mod_authnz_ldap.c Thu Jul 19 14:05:16 2007
@@ -57,7 +57,7 @@
     char **attributes;              /* Array of all the attributes to return */
     int scope;                      /* Scope of the search */
     char *filter;                   /* Filter to further limit the search  */
-    int deref;                      /* how to handle alias dereferening */
+    deref_options deref;            /* how to handle alias dereferening */
     char *binddn;                   /* DN to bind to server (can be NULL) */
     char *bindpw;                   /* Password to bind to server (can be NULL) */
 

Modified: httpd/httpd/trunk/modules/ldap/util_ldap.c
URL: http://svn.apache.org/viewvc/httpd/httpd/trunk/modules/ldap/util_ldap.c?view=diff&rev=557772&r1=557771&r2=557772
==============================================================================
--- httpd/httpd/trunk/modules/ldap/util_ldap.c (original)
+++ httpd/httpd/trunk/modules/ldap/util_ldap.c Thu Jul 19 14:05:16 2007
@@ -441,7 +441,7 @@
             uldap_connection_find(request_rec *r,
                                   const char *host, int port,
                                   const char *binddn, const char *bindpw,
-                                  int deref, int secure)
+                                  deref_options deref, int secure)
 {
     struct util_ldap_connection_t *l, *p; /* To traverse the linked list */
     int secureflag = secure;
--- httpd/httpd/trunk/include/util_ldap.h (original)
+++ httpd/httpd/trunk/include/util_ldap.h Thu Jul 19 14:05:16 2007
@@ -96,7 +96,7 @@
 
     const char *host;                   /* Name of the LDAP server (or space separated list) */
     int port;                           /* Port of the LDAP server */
-    int deref;                          /* how to handle alias dereferening */
+    deref_options deref;                /* how to handle alias dereferening */
 
     const char *binddn;                 /* DN to bind to server (can be NULL) */
     const char *bindpw;                 /* Password to bind to server (can be NULL) */
@@ -206,11 +206,11 @@
  *      use this connection while it is busy. Once you are finished with a connection,
  *      apr_ldap_connection_close() must be called to release this connection.
  * @fn util_ldap_connection_t *util_ldap_connection_find(request_rec *r, const char *host, int port,
  *                                                           const char *binddn, const char *bindpw, int deref,
  *                                                           int netscapessl, int starttls)
  */
 APR_DECLARE_OPTIONAL_FN(util_ldap_connection_t *,uldap_connection_find,(request_rec *r, const char *host, int port,
-                                                  const char *binddn, const char *bindpw, int deref,
+                                                  const char *binddn, const char *bindpw, deref_options deref,
                                                   int secure));
 
 /**
@@ -206,11 +206,11 @@
  *      apr_ldap_connection_close() must be called to release this connection.
  * @fn util_ldap_connection_t *util_ldap_connection_find(request_rec *r, const char *host, int port,
- *                                                           const char *binddn, const char *bindpw, int deref,
+ *                                                           const char *binddn, const char *bindpw, deref_options deref,
  *                                                           int netscapessl, int starttls)
  */

Modified: httpd/httpd/trunk/modules/aaa/mod_authnz_ldap.c
URL: http://svn.apache.org/viewvc/httpd/httpd/trunk/modules/aaa/mod_authnz_ldap.c?view=diff&rev=557772&r1=557771&r2=557772
==============================================================================